## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(ClustAll)

## -----------------------------------------------------------------------------
data("BreastCancerWisconsin", package = "ClustAll") # load example data
# remove patients ID, as it is not a clinical variable
data_use <- subset(wdbc,select=-ID)
str(data_use)

## -----------------------------------------------------------------------------
obj_noNA <- createClustAll(data = data_use, colValidation = "Diagnosis",
                            nImputation = NULL, dataImputed = NULL)

## ----results=FALSE------------------------------------------------------------
obj_noNA1 <- runClustAll(Object = obj_noNA, threads = 8, simplify = FALSE)
obj_noNA1simplify <- runClustAll(Object = obj_noNA, threads = 8,
                                simplify = TRUE)

tNOsimplify <- system.time(runClustAll(Object = obj_noNA, threads = 8,
                                        simplify = FALSE))
tYESsimplify <- system.time(runClustAll(Object = obj_noNA, threads = 8, 
                                        simplify = TRUE))

## -----------------------------------------------------------------------------
print(tNOsimplify)
print(tYESsimplify)

## ----results=FALSE, warning=FALSE---------------------------------------------
plotJACCARD(Object = obj_noNA1, stratification_similarity =  0.7)
plotJACCARD(Object = obj_noNA1, stratification_similarity = 0.6)
plotJACCARD(Object = obj_noNA1, stratification_similarity = 0.9)
plotJACCARD(Object = obj_noNA1, stratification_similarity = 0.88)
plotJACCARD(Object = obj_noNA1simplify, stratification_similarity = 0.88)

## -----------------------------------------------------------------------------
resStratification(Object = obj_noNA1, population = 0.05, 
                    stratification_similarity = 0.88, all = FALSE)

## -----------------------------------------------------------------------------
plotSANKEY(Object = obj_noNA1, clusters = c("cuts_c_3","cuts_a_9"), 
            validationData = FALSE)
plotSANKEY(Object = obj_noNA1, clusters = c("cuts_c_3","cuts_b_13"), 
            validationData = FALSE)
plotSANKEY(Object = obj_noNA1, clusters = "cuts_c_3", validationData = TRUE)
plotSANKEY(Object = obj_noNA1, clusters = "cuts_b_13", validationData = TRUE)

## -----------------------------------------------------------------------------
df <- cluster2data(Object = obj_noNA1, 
                    clusterName = c("cuts_c_3","cuts_a_9","cuts_b_13"))

## -----------------------------------------------------------------------------
# STRATIFICATION 1
validateStratification(obj_noNA1, "cuts_a_9")

## -----------------------------------------------------------------------------
# STRATIFICATION 2
validateStratification(obj_noNA1, "cuts_b_13")

## -----------------------------------------------------------------------------
# STRATIFICATION 3
validateStratification(obj_noNA1, "cuts_c_3")

## -----------------------------------------------------------------------------
data("BreastCancerWisconsinMISSING", package = "ClustAll")
data_use_NA <- wdbcNA
colSums(is.na(data_use_NA)) # dataset present NAs

obj_NA <- createClustAll(data_use_NA, nImputation = 5,  
                            colValidation = "Diagnosis") 

# The rest of the pipeline follows as a)

## ----results=FALSE------------------------------------------------------------
obj_NA1 <- runClustAll(obj_NA, threads = 8) 

## ----results=FALSE, warning=FALSE---------------------------------------------
plotJACCARD(Object = obj_NA1, stratification_similarity = 0.9)

## -----------------------------------------------------------------------------
resStratification(Object = obj_NA1, population = 0.05, 
                    stratification_similarity = 0.88, all = FALSE)

## -----------------------------------------------------------------------------
df_NA <- cluster2data(Object = obj_NA1, clusterName = c("cuts_a_4"))

## -----------------------------------------------------------------------------
library(mice)
data("BreastCancerWisconsinMISSING", package = "ClustAll") # load example data
data_use_NA <- wdbcNA
str(data_use_NA)

imp_data_use <- mice(data_use_NA[-1], m=5, maxit = 5,seed=1234, print=FALSE)

## -----------------------------------------------------------------------------
# dataImputed contains the mids object with the imputed
obj_imp <- createClustAll(data=data_use_NA, dataImputed = imp_data_use, 
                            colValidation = "Diagnosis") 

# The rest of the pipeline follows as a)

## ----results=FALSE------------------------------------------------------------
obj_imp1 <- runClustAll(obj_imp, threads = 8)

## ----results=FALSE, warning=FALSE---------------------------------------------
plotJACCARD(Object = obj_imp1, stratification_similarity = 0.9)

## -----------------------------------------------------------------------------
resStratification(Object = obj_imp1, population = 0.05, 
                    stratification_similarity = 0.9, all = FALSE)

## -----------------------------------------------------------------------------
df_imp <- cluster2data(Object = obj_NA1, 
                        clusterName = c("cuts_a_1", "cuts_a_16"))

validateStratification(obj_noNA1, "cuts_a_1")
validateStratification(obj_noNA1, "cuts_a_16")

## -----------------------------------------------------------------------------
sessionInfo()

